# z\_defaults Role

This role sets default variables for the Catamaran project. It can be used to configure base settings required for the project's infrastructure.

## Requirements

- Ansible 2.9 or higher
- Supported platforms:
  - EL 7
  - EL 8

## Role Variables


## Example Playbook

```yaml
- hosts: all
  roles:
    - role: z_defaults
```
